#! /usr/bin/env bash

alias @=bluer_ai

alias @build_README=bluer_ai_build_README

alias @clear="cd; clear"

alias @conda=bluer_ai_conda

alias @docker=bluer_ai_docker

alias @git=bluer_ai_git
alias @git++="bluer_ai_git increment_version"

alias @gpu=bluer_ai_gpu

alias @init=bluer_ai_init

alias @latex=bluer_ai_latex

alias @log=bluer_ai_log
alias @error=bluer_ai_log_error
alias @warn=bluer_ai_log_warning

alias @mac='if [ "$abcli_is_mac" == true ]; then'
alias @rpi='if [ "$abcli_is_rpi" == true ]; then'
alias @.='fi'

alias @perform_action=bluer_ai_perform_action

alias @plugins=bluer_ai_plugins

alias @pypi=bluer_ai_pypi

alias @screen=bluer_ai_screen

alias @seed=bluer_ai_seed

alias @session=bluer_ai_session

alias @ssh=bluer_ai_ssh

alias @ssm=bluer_ai_ssm

alias @terraform=bluer_ai_terraform

alias @version="bluer_ai version"

alias @wifi=bluer_ai_wifi
